function looperServiceProvider() {
    var defaults = this.defaults = {
        interval: 5000,
        activeProperty: 'active'
    };

    this.configure = function(options) {
        if (!options) options = {};

        if (options.interval !== undefined) defaults.interval = options.interval;
        if (options.activeProperty) defaults.activeProperty = options.activeProperty;
    };

    this.$get = ['$timeout', function($timeout) {

        function looper(options) {
            if (!options) options = {};

            this.items = options.items || [];
            this.index = -1;
            this.current = null;
            this.interval = options.interval || defaults.interval;
            this.activeProperty = options.activeProperty || defaults.activeProperty;
            this.timeout = undefined;
            this.running = false;

            this.start = start;
            this.next = next;
            this.previous = previous;
            this.setCurrent = setCurrent;
            this.stop = stop;

            if (this.items.length > 0) {
                this.setCurrent(0);
            }

            return this.start();
        }

        function start() {
            var self = this;
            self.running = true;

            $timeout.cancel(self.timeout);
            self.timeout = $timeout(function() {
                self.next();
            }, self.interval);

            return this;
        }

        function next() {
            if (this.index < this.items.length - 1) this.index++;
            else this.index = 0;

            this.setCurrent(this.index);
            this.start();
        }

        function previous() {
            if (this.index > 0) this.index--;
            else this.index = this.items.length - 1;

            this.current = this.setCurrent(this.index);
            this.start();
        }

        function setCurrent(index) {
            var self = this;
            
            self.items.forEach(function(i) {
                i[self.activeProperty] = false;
            });

            self.index = index;
            if (index >= 0 && index < self.items.length) {
                self.current = self.items[self.index];
                self.current[self.activeProperty] = true;
            } else {
                self.current = null;
            }
        }

        function stop() {
            self.running = false;
            $timeout.cancel(this.timeout);
        }

        return looper;
    }];
}
